@@ -6,6 +6,9 @@ from . import utilities
 from . import integrators
 
 from .integrators import available_methods
-from . import tests
-from .utilities import tests
-from .exception_types import tests
\ No newline at end of file
+try:
+    from . import tests
+    from .utilities import tests
+    from .exception_types import tests
+except ImportError:
+    pass
\ No newline at end of file
